# Github Projects Fetcher  (gp-fetcher)

- This a tool to fetch your github project details so that your time for writing an API is saved.
- Simple to use tool made in Python with bs4(Beautiful Soup)

### If you want to skip the documentation section then checkout the video [here](https://youtu.be/ixFnCXu9r6Q)

## Documentation


- First clone this repo to your machine

*Assuming python and pip installed on your system*

- *Checkout resources to install [python](https://www.python.org/downloads/) and [pip](https://packaging.python.org/tutorials/installing-packages/) if not installed*

___
#### Installing the requirements is necessary for the code to run

- Into the root of this project run the following code
```python

pip3 install -r requirements.txt for linux and mac
pip install -r requirements.txt for windows

```

- Then run the python file by using the commands below  

```bash 
python3 scrape.py   for linux and mac
python scrape.py for windows
```

- You will be prompted to enter details on terminal
```python
  Enter your username: #enter the github user name here
```

- After you get the message below check your root for this project and your file must be generated over there as a json file that can be used in your projects

```python
  Done! checkout your {github-username-here}-projects.json file at the root of this project directory
```
___
## You are done!

```text
go ahead and use this json to parse in your project 
```

___
# Author
## Gautam Chandra Saha

2021 &copy; Gautam Chandra Saha
## License

[MIT](https://choosealicense.com/licenses/mit/)

  
